#include <AGL/agl.h>

/*aglChoosePixelFormat

Creates a pixel format object that satisfies the constraints of the specified buffer and renderer attributes.

AGLPixelFormat aglChoosePixelFormat (
   const AGLDevice *gdevs,
   GLint ndev,
   const GLint *attribs);
Parameters
gdevs

A pointer to an AGLDevice data type that contains an array of Mac OS graphics devices. AGL chooses pixel formats and renderers that are appropriate for these devices. To create a pixel format object that supports all devices on the system, pass NULL.
ndev

The number of graphics devices that your application supplies in the gdevs parameter. Pass 0 if you also pass NULL for the gdevs parameter.
attribs

A NULL terminated array that contains a list of buffer and renderer attributes. The existence of a Boolean attribute implies a true value. If an attribute is not Boolean in nature, you must supply the desired value immediately following the attribute. For information on the attributes that you can supply, see “Buffer and Renderer Attributes”. I
Return Value

A new pixel format object that contains pixel format information and a list of virtual screens. Returns NULL if the system cannot find a pixel format and virtual screen that satisfies the constraints of the buffer and renderer attributes.
Discussion

After a pixel format object is created successfully, the integer attributes are set to values that are as close to the desired value as can be provided by the system. Attribute values can differ for each virtual screen. You can use the AGL_MINIMUM_POLICY and AGL_MAXIMUM_POLICY attributes to control how the system chooses the setting. For more information on choosing attributes, see OpenGL Programming Guide for Mac OS X.
Availability
Available in Mac OS X v10.0 and later.
Declared In
agl.h
See Also
aglCreateContext
aglDescribePixelFormat
aglDestroyPixelFormat*/

AGLPixelFormat aglChoosePixelFormat (
   const AGLDevice *gdevs,
   GLint ndev,
   const GLint *attribs){};

/*aglCreateContext

Creates an AGL rendering context.

AGLContext aglCreateContext (
   AGLPixelFormat pix,
   AGLContext share);
Parameters
pix

A pixel format object creating by calling the function aglChoosePixelFormat.
share

The rendering context with which to share the OpenGL object state—including texture objects, programs and shader display lists, vertex array objects, vertex buffer objects, pixel buffer objects, and frame buffer objects—and the object state associated which each of these object types. Pass NULL to indicate that no sharing is to take place. 
Return Value

A new rendering context. The aglCreateContext function returns NULL if the function fails for any reason. You can call the function aglGetError to determine what the error is.
Discussion

If the pixel format object you supply is able to support multiple graphics devices, then the rendering context can render transparently across the supported devices. With a multiple-device rendering context, sharing is possible only when the relationship between the renderers and the graphics devices they support is the same for all rendering contexts that are shared. Normally you achieve the best results by using the same pixel format object for all shared rendering contexts. For more information, see OpenGL Programming Guide for Mac OS X.
Availability
Available in Mac OS X v10.0 and later.
Declared In
agl.h
See Also
aglChoosePixelFormat
aglDestroyContext
aglSetDrawable*/

AGLContext aglCreateContext (
   AGLPixelFormat pix,
   AGLContext share){};

/*aglGetError

Returns an AGL error code.

GLenum aglGetError (void);
Return Value

The value of the global AGL error flag. See “Error Codes” for a complete description of the error codes that can be returned.
Discussion

This function is similar to the OpenGL function glGetError. You call the function aglGetError whenever an AGL function returns TRUE to retrieve the error code associated with the error condition. Each error is assigned a numeric code and a symbolic name. When an error occurs, the error flag is set to the appropriate error code value. No other errors are recorded until aglGetError is called, the error code is returned, and the flag is reset to AGL_NO_ERROR. If a call to aglGetError returns AGL_NO_ERROR, this means that there has been no detectable error since the last call to aglGetError.
Availability
Available in Mac OS X v10.0 and later.
Declared In
agl.h
See Also
aglErrorString*/
GLenum aglGetError (void){};


/*aglGetCGLContext

Gets the CGL rendering context associated with an AGL rendering context.

GLboolean aglGetCGLContext (
   AGLContext ctx,
   void **cgl_ctx);
Parameters
ctx

An AGL rendering context.
cgl_ctx

On return, points to the CGL rendering context associated with the specified AGL rendering context.
Return Value

Returns GL_FALSE if it fails for any reason, GL_TRUE otherwise. If an error occurs, call the function aglGetError to determine what the error is.
Discussion

You should use this function only when you absolutely need to use a non-AGL function that requires an CGL rendering context. You can cast the returned CGL rendering context to another data type as needed. Note that destroying the AGL rendering context also destroys the CGL rendering context, thus rendering the data reference returned by this function invalid.

Note: Always use the AGL version of a function when available, because there is additional work that AGL must perform to be compatible with Carbon.

Availability
Available in Mac OS X v10.4 and later.
Declared In
agl.h*/

GLboolean aglGetCGLContext (
   AGLContext ctx,
   void **cgl_ctx){};


/*aglSetDrawable

Attaches a rendering context to a Carbon window.

GLboolean aglSetDrawable (
   AGLContext ctx,
   AGLDrawable draw);
Parameters
ctx

A rendering context returned by the function aglCreateContext.
draw

The drawable object—which must be a Carbon window—to attach to the AGL rendering context. You need to supply a CGrafPtr data type obtained from a valid window. The Window Manager function GetWindowPort returns the CGrafPtr associated with a Carbon window. To disable rendering for a rendering context, pass NULL. 
Return Value

Returns GL_FALSE if it fails for any reason, GL_TRUE otherwise. If an error occurs, call the function aglGetError to determine what the error is.
Discussion

After calling this function, AGL directs subsequent OpenGL rendering calls to the specified rendering context to modify the window content. In addition, the function aglSetDrawable performs all of the actions performed by aglUpdateContext.

When a rendering context is initially attached to the window, its viewport is set to the full size of the window. If the rendering context is subsequently attached to the same window, its viewport is unaltered.
Availability
Available in Mac OS X v10.0 and later.
Declared In
agl.h
See Also
aglGetDrawable*/
GLboolean aglSetDrawable (
   AGLContext ctx,
   AGLDrawable draw){};

/*aglSetInteger

Sets the value of an option for a rendering context.

GLboolean aglSetInteger (
   AGLContext ctx,
   GLenum pname,
   const GLint *params);
Parameters
ctx

A rendering context.
pname

The rendering context option whose value you want to set. You can pass any of the constants listed in “Context Options and Parameters” that have an associated integer value.
params

A pointer to the value to set the parameter to.
Return Value

Returns GL_FALSE if it fails for any reason, GL_TRUE otherwise. If an error occurs, call the function aglGetError to determine what the error is.
Discussion

Use aglEnable to enable the option.
Availability
Available in Mac OS X v10.0 and later.
Declared In
agl.h
See Also
aglGetInteger*/
GLboolean aglSetInteger (
   AGLContext ctx,
   GLenum pname,
   const GLint *params){};


/*aglGetCGLPixelFormat

Gets the CGL pixel format object associated with an AGL pixel format.

GLboolean aglGetCGLPixelFormat (
   AGLPixelFormat pix,
   void **cgl_pix);
Parameters
pix

An AGL pixel format object.
cgl_pix

On return, points to the CGL pixel format object associated with the specified AGL pixel format.
Return Value

Returns GL_FALSE if it fails for any reason, GL_TRUE otherwise. If an error occurs, call the function aglGetError to determine what the error is.
Discussion

You should use this function only when you absolutely need to pass a CGL pixel format object to a non-AGL function. You can cast the returned CGL pixel format object to another data type as needed. Note that destroying the AGL pixel format object also destroys the CGL pixel format object, thus making the data reference returned invalid.

Note: Always use the AGL version of a function when available, because there is additional work that AGL must perform to be compatible with Carbon.

Availability
Available in Mac OS X v10.4 and later.
Declared In
agl.h*/

GLboolean aglGetCGLPixelFormat (
   AGLPixelFormat pix,
   void **cgl_pix){};


/*aglSetCurrentContext

Sets the specified rendering context as the current rendering context.

GLboolean aglSetCurrentContext (
   AGLContext ctx);
Parameters
ctx

The rendering context to set as the current rendering context. Pass NULL to release the current rendering context without assigning a new one.
Return Value

Returns GL_FALSE if it fails for any reason, GL_TRUE otherwise. If an error occurs, call the function aglGetError to determine what the error is.
Discussion

There can be only one current rendering context. Subsequent OpenGL rendering calls operate on the current rendering context to modify the drawable object associated with it. 

You can use AGL macros to bypass the current rendering context mechanism and maintain your own current rendering context.

A context is current on a per-thread basis. Multiple threads must serialize calls into the same context.
Availability
Available in Mac OS X v10.0 and later.
Declared In
agl.h
See Also
aglGetCurrentContext*/
GLboolean aglSetCurrentContext (
   AGLContext ctx){};


/*aglErrorString

Returns a string that describes the specified AGL error code.

const GLubyte *aglErrorString (
   GLenum code);
Parameters
code

An AGL error code returned by the function aglGetError. For a description of these constants, see “Error Codes”.
Return Value

An error string that describes the error code passed in the code parameter. If the code is invalid, returns the string “No such error code.”
Availability
Available in Mac OS X v10.0 and later.
Declared In
agl.h
See Also
aglGetError*/
const GLubyte *aglErrorString (
   GLenum code){};


/*aglSurfaceTexture

Allows texturing from a drawable object that has an attached rendering context, using the surface contents as the source data for the texture.

void aglSurfaceTexture (
   AGLContext context,
   GLenum target,
   GLenum internalformat,
   AGLContext surfacecontext);
Parameters
context

A rendering context attached to the window that's the target of the texture operation.
target

A constant that specifies an OpenGL target texture. You can supply any of the texture targets defined by the OpenGL specification, including: 
GL_TEXTURE_2D, a texture whose dimensions are a power of two.
GL_TEXTURE_RECTANGLE_EXT, a texture whose dimensions are not a power of two.
GL_TEXTURE_CUBE_MAP, a mapped cube texture.
internalformat

A constant that specifies the internal color format of the texture— either GL_RGB or GL_RGBA.
surfacecontext

A rendering context that's attached to the window that's the source of the texture data.
Discussion

The aglSurfaceTexture function behaves similar to the function glTexImage2D. The texture target and internal format must be supported by the renderer of the target rendering context, and the geometry of the source drawable object must be compatible with the texture target. For example, if the texture target is GL_TEXTURE_2D, the window must conform to power-of-two dimensions.

Before calling this function you must use OpenGL calls to set up the OpenGL texture referred to by the target parameter. That is, enable texturing, generate a texture name, bind it to a texture target, and so forth. For more information, see OpenGL Programming Guide.

The target and source windows must use the same renderer (virtual screen) or the function fails, most typically by not texturing the target rendering context.

An error condition occurs if the surface rendering context is not attached to a windowed drawable object; the drawable object cannot be an offscreen area or pixel buffer. It’s also possible to get standard OpenGL errors similar to the errors that can occur for the function glTexImage2D. Use the function glError to query OpenGL errors.

Note: Although the function aglSurfaceTexture provides a flexible way to render to an offscreen texture and then use it as a source, you should consider using pixel buffer objects or OpenGL framebuffer objects instead. For details on using a hidden window as a texture source, see OpenGL Programming Guide for Mac OS X. This document also describes how to use pixel buffer objects and framebuffer objects as texture sources.

Availability
Available in Mac OS X v10.2 and later.
Declared In
agl.h*/

void aglSurfaceTexture (
   AGLContext context,
   GLenum target,
   GLenum internalformat,
   AGLContext surfacecontext){};

/*aglDestroyContext

Frees the resources associated with a rendering context.

GLboolean aglDestroyContext (
   AGLContext ctx);
Parameters
ctx

The rendering context whose resources you want to release. 
Return Value

Returns GL_FALSE if it fails for any reason, GL_TRUE otherwise. If an error occurs, call the function aglGetError to determine what the error is.
Discussion

This function frees all the resources used by the rendering context passed to it. If the rendering context that you pass is the current rendering context, the current context is set to NULL and there is no current rendering context after the function executes.

After you call this function, you must make sure that you do not use the destroyed rendering context. This includes using AGL macros in which the rendering context is explicitly passed to OpenGL.
Availability
Available in Mac OS X v10.0 and later.
Declared In
agl.h
See Also
aglCreateContext
aglUpdateContext*/

GLboolean aglDestroyContext (
   AGLContext ctx){};


/*aglDestroyPixelFormat

Frees the memory associated with a pixel format object.

void aglDestroyPixelFormat (
   AGLPixelFormat pix);
Parameters
pix

The pixel format object whose resources you want to release. This must be a pixel format object returned by the functionaglChoosePixelFormat. AGL sets a AGL_BAD_PIXELFMT error if you pass the returned value from the function aglNextPixelFormat or the pix parameter is not a valid pixel format.
Discussion

A copy of the pixel format data is made by the aglCreateContext function, so your application can free a pixel format immediately after creating a rendering context with it. On the other hand, a pixel format object can be useful for enumerating virtual screens when multiple renderers are supported, so you may want to retain it.
Availability
Available in Mac OS X v10.0 and later.
Declared In
agl.h
See Also
aglDescribePixelFormat*/

void aglDestroyPixelFormat (
   AGLPixelFormat pix){};


/*aglSwapBuffers

Exchanges the front and back buffers of the specified rendering context.

void aglSwapBuffers (
   AGLContext ctx);
Parameters
ctx

The rendering context whose buffers you want to swap. AGL sets the AGL_BAD_CONTEXT error if the ctx parameter is not a valid AGL rendering context.
Discussion

The aglSwapBuffers function either swaps the buffers or copies the back buffer content to the front buffer. Before it returns, aglSwapBuffers invokes the OpenGL function glFlush.

To synchronize with a monitor retrace, set the current swap interval (AGL_SWAP_INTERVAL) to 1 by calling the function aglSetInteger. 
Availability
Available in Mac OS X v10.0 and later.
Declared In
agl.h*/
void aglSwapBuffers (
   AGLContext ctx){};


/*aglUpdateContext

Notifies the rendering context that the window geometry has changed.

GLboolean aglUpdateContext (
   AGLContext ctx);
Parameters
ctx

The rendering context that needs updating. 
Return Value

Returns GL_FALSE if it fails for any reason, GL_TRUE otherwise. If an error occurs, call the function aglGetError to determine what the error is.
Discussion

You must call the aglUpdateContext function any time that the geometry of the drawable object changes. You should call this function after the completion of any move or resize action.
Availability
Available in Mac OS X v10.0 and later.
Declared In
agl.h
See Also
aglSetDrawable*/
GLboolean aglUpdateContext (
   AGLContext ctx){};









